==> hubzero-submit-monitors_2.5.1.orig.tar.gz: hubzero-submit-monitors-2.5.1/monitorJobS.py <==
#!/usr/bin/env python
#
# @package      hubzero-submit-monitors
# @file         monitorJobS.py
# @author       Steven Clark <clarks@purdue.edu>
# @copyright    Copyright (c) 2004-2013 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2004-2013 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#
# ----------------------------------------------------------------------
#  monitorJobS.py
#
#  script which notifies monitorJob.py of a new job submission
#
import sys

from hubzero.submit.RemoteJobMonitor import RemoteJobMonitor

JOBMONITORHOST = ""
JOBMONITORPORT = 5727

def monitorJobS():
   """new job Submission"""
   messageSite    = sys.argv[1]
   remoteJobId    = sys.argv[2]
   hubUserId      = sys.argv[3]
   enteredCommand = sys.argv[4]
   localJobId     = sys.argv[5]
   instanceId     = sys.argv[6]
   destination    = sys.argv[7]
   runName        = sys.argv[9]
   nCores         = sys.argv[9]
   distributorPid = sys.argv[10]

   remoteJobMonitor = RemoteJobMonitor(JOBMONITORHOST,JOBMONITORPORT)

   remoteJobMonitor.postJobSubmission(messageSite,remoteJobId,
                                      hubUserId,enteredCommand,localJobId,instanceId,destination,runName,nCores,distributorPid)


if __name__ == '__main__':
   monitorJobS()

==> hubzero-submit-monitors_2.7.1.5.orig.tar.gz: hubzero-submit-monitors-2.7.1.5/monitorJobS.py <==
#!/usr/bin/env python
#
# @package      hubzero-submit-monitors
# @file         monitorJobS.py
# @author       Steven Clark <clarks@purdue.edu>
# @copyright    Copyright (c) 2004-2014 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2004-2014 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#
# ----------------------------------------------------------------------
#  monitorJobS.py
#
#  script which notifies monitorJob.py of a new job submission
#
import sys
import logging

from hubzero.submit.RemoteJobMonitor import RemoteJobMonitor

JOBMONITORHOST = ""
JOBMONITORPORT = 5727

APPLICATIONLOGGER = logging.getLogger('') 

def openLogger():
   class EmptyFilter(logging.Filter):
      """
      This is a filter which rejects empty messages

      """

      def filter(self,record):
         if record.getMessage() == "":
            emptyRecord = True
         else:
            emptyRecord = False

         return(not emptyRecord)

   APPLICATIONLOGGER.setLevel(logging.DEBUG)

   logHandler = logging.StreamHandler()

   emptyFilter = EmptyFilter()
   logHandler.addFilter(emptyFilter)

   logFormatter = logging.Formatter('%(asctime)s %(message)s','[%a %b %d %H:%M:%S %Y]')
   logHandler.setFormatter(logFormatter)
   APPLICATIONLOGGER.addHandler(logHandler)


def monitorJobS():
   """new job Submission"""
   messageSite    = sys.argv[1]
   remoteJobId    = sys.argv[2]
   hubUserId      = sys.argv[3]
   enteredCommand = sys.argv[4]
   localJobId     = sys.argv[5]
   instanceId     = sys.argv[6]
   destination    = sys.argv[7]
   runName        = sys.argv[9]
   nCores         = sys.argv[9]
   distributorPid = sys.argv[10]

   remoteJobMonitor = RemoteJobMonitor(JOBMONITORHOST,JOBMONITORPORT)

   remoteJobMonitor.postJobSubmission(messageSite,remoteJobId,
                                      hubUserId,enteredCommand,localJobId,instanceId,destination,runName,nCores,distributorPid)


if __name__ == '__main__':
   openLogger()
   monitorJobS()
